<?php
ini_set('memory_limit', '-1');
class ListacitasF extends CI_Controller
{
	
	function __construct()
	{
		parent::__construct();
		
		$this->load->model('agenda/franquiciatario/agendaF_model');
		$this->load->library(array('session','form_validation'));
	}

	public function index(){
		if($this->session->userdata('Rol_IdRol')==FALSE || 
			$this->session->userdata('Rol_IdRol') == '1'|| 
			$this->session->userdata('Rol_IdRol') == '3')
		{
			redirect(base_url().'acceso/acceso');
		} else {
			
    		$data['Franquicias']=$this->agendaF_model->BuscarFranquicia(); 
		 	foreach ($data['Franquicias'] as $i => $Franquicias) 
			$this->db->select('*');
			$this->db->join('franquicias','Franquicias_IdFranquicias=IdFranquicias','inner');
			$this->db->where('Franquicias_IdFranquicias',$i);
			$data['consulta']=$this->db->get('agenda')->result();

		$this->load->view('layout/headerFran');
		$this->load->view('layout/menuFranquicia');
		$data['cabinas']=$this->cabinas(); 
		$data['ReCabina']=$this->agendaF_model->BuscarCabina(); 
		$data['ReCategoria']=$this->agendaF_model->BuscarCategoria();
		$data['ReEstatusCita']=$this->agendaF_model->BuscarEstatusCita();
		$data['ReUsuario']=$this->agendaF_model->BuscarUsuario();
		$this->load->view('agenda/franquiciatario/agendaF_view',$data);
		$this->load->view('layout/footer');


	}}

	public function listacitasFAct(){
		if($this->session->userdata('Rol_IdRol')==FALSE || 
			$this->session->userdata('Rol_IdRol') == '1'|| 
			$this->session->userdata('Rol_IdRol') == '3'){
			redirect(base_url().'acceso/acceso');
		} else {			
    		$data['Franquicias']=$this->agendaF_model->BuscarFranquicia(); 
		 	foreach ($data['Franquicias'] as $i => $Franquicias) 
			$this->db->select('*');
			$this->db->join('franquicias','Franquicias_IdFranquicias=IdFranquicias','inner');
			$this->db->where('Franquicias_IdFranquicias',$i);
			$data['consulta']=$this->db->get('agenda')->result();

			$this->load->view('layout/headerFran');
			$this->load->view('layout/menuFranquicia');
			$data['cabinas']=$this->cabinas(); 
			$data['ReCabina']=$this->agendaF_model->BuscarCabina(); 
			$data['ReCategoria']=$this->agendaF_model->BuscarCategoria();
			$data['ReEstatusCita']=$this->agendaF_model->BuscarEstatusCita();
			$data['ReUsuario']=$this->agendaF_model->BuscarUsuario();
			$this->load->view('myagenda/franquiciatario/agendaF_view',$data);
			$this->load->view('layout/footer');
		}
	}

	public function cabinas()
	{
		$cabinasExistentes=$this->agendaF_model->BuscarCabina();
		$i=0;
		foreach($cabinasExistentes as $i => $cabina)
		{
			$colores[$i]['id'] = $i;
			$colores[$i]['nombre'] = $cabina;
			switch($cabina)
			{
				case 'FACIAL':
					$colores[$i]['color'] = 'facial';
					break;
				case 'FACIAL 2':
					$colores[$i]['color'] = 'facial-2';
					break;
				case 'CORPORAL':
					$colores[$i]['color'] = 'corporal';
					break;
				case 'CORPORAL 2':
					$colores[$i]['color'] = 'corporal-2';
					break;
				case 'RELAJANTES/MASAJES':
					$colores[$i]['color'] = 'relajantes-masajes';
					break;
				case 'CAVITACION':
					$colores[$i]['color'] = 'cavitacion';
					break;
				case 'IPL/E-LIGHT':
					$colores[$i]['color'] = 'ipl-e-light';
					break;
				case 'PESTAÑAS':
					$colores[$i]['color'] = 'pestañas';
					break;
				case 'SAUNA':
					$colores[$i]['color'] = 'sauna';
					break;
				case 'SAUNA 2':
					$colores[$i]['color'] = 'sauna-2';
					break;
				case 'ADICIONAL':
					$colores[$i]['color'] = 'adicional';
					break;
				case 'CAPSULA INFRAROJA':
					$colores[$i]['color'] = 'capsula-infraroja';
					break;
				case 'UÑAS 1':
					$colores[$i]['color'] = 'uñas-1';
					break;
				case 'UÑAS 2':
					$colores[$i]['color'] = 'uñas-2';
					break;
				case 'UÑAS 3':
					$colores[$i]['color'] = 'uñas-3';
					break;
				default;
				$colores[$i]['color'] = 'blanco';
				break;
			}
			
			$i++;
			
		}
		
		return ($colores);
	}
	public function service(){
		$codigo = $this->input->post('codeService');
		/*echo  json_encode("codigo service".$codigo);*/
		$this->agendaF_model->BuscarServiciosNombre($codigo);
	}
	public function loadNamePromo(){
		$codigo = $this->input->post('codePromo');
		/*echo  json_encode("codigo service".$codigo);*/
		$this->agendaF_model->BuscarPromocionesNombre($codigo);
	}

	public function buscarporcabina (){ 
		$query2 = $this->input->get('query', TRUE);
		$r = $this->agendaF_model->buscarporcabina($query2);
		echo json_encode($r);
	}


	public function getEventos(){
		$filtro = $this->input->post('codecabina');
		$datosProcesados=[]; 
		$r = $this->agendaF_model->getEventos($filtro);
		
		echo json_encode($r);
		/*echo json_encode($r);*/
	}

	public function getEventos1(){
		$r = $this->agendaF_model->getEventos();
		echo json_encode($r);
	}

	// public function updEvento(){
	// 	$param['IdAgenda'] = $this->input->post('IdAgenda');
	// 	$param['Fecha'] = $this->input->post('Fecha');
	// 	//$param['fecfin'] = $this->input->post('fecfin');

	// 	$r = $this->agendaF_model->updEvento($param);

	// 	echo $r;
	// }

	public function deleteEvento(){

		$id = $this->input->post('IdAgenda');
		$r = $this->agendaF_model->deleteEvento($id);
		echo $r;
	}

	public function enviaDatos(){
		if($this->session->userdata('Rol_IdRol')==FALSE || 
			$this->session->userdata('Rol_IdRol') == '1'|| 
			$this->session->userdata('Rol_IdRol') == '3')
		{
			redirect(base_url().'acceso/acceso');
		} else {
		$id= $this->uri->segment(5);
		$result = $this->agendaF_model->BuscaCliente($id);
		if(count($result)>0){
				foreach ($result as $row){
				$IdClientes = $row->IdClientes;
				$NombreCliente=$row->NombreCliente;
				} 
					$datos = array(
						'IdClientes' => $IdClientes,
						'NombreCliente' => $NombreCliente,
					);
				}
				else{}
				
		$this->load->view('layout/headerFran');
		$this->load->view('layout/menuFranquicia');
		$datos['ReCabina']=$this->agendaF_model->BuscarCabina();
	    $datos['ReFranquicia']=$this->agendaF_model->BuscarFranquicia();
	    $datos['ReUsuario']=$this->agendaF_model->BuscarUsuario();
	    $datos['ReCategoria']=$this->agendaF_model->BuscarCategoria();
		// // $datos['ReCliente']=$this->agendaF_model->BuscarCliente();
		// $datos['ReServicios']=$this->agendaF_model->BuscarServicios();
		// $datos['RePromocionesInstitucionales']=$this->agendaF_model->BuscarPromocionesinstitucionales();
		// $datos['RePromocionesLocales']=$this->agendaF_model->BuscarPromocionesLocales();
		 $datos['ReEstatusCita']=$this->agendaF_model->BuscarEstatusCita();
		$this->load->view('agenda/franquiciatario/agregarcitaF_view',$datos);
		$this->load->view('layout/footer');
	 }

	}




	public function agregar(){
		if($this->session->userdata('Rol_IdRol')==FALSE || 
			$this->session->userdata('Rol_IdRol') == '1'|| 
			$this->session->userdata('Rol_IdRol') == '3')
		{
			redirect(base_url().'acceso/acceso');
		} else {
		
					
		$this->load->view('layout/headerFran');
		$this->load->view('layout/menuFranquicia');
		$datos['ReCabina']=$this->agendaF_model->BuscarCabina();
	    $datos['ReFranquicia']=$this->agendaF_model->BuscarFranquicia();
	    $datos['ReUsuario']=$this->agendaF_model->BuscarUsuario();
	    $datos['ReCategoria']=$this->agendaF_model->BuscarCategoria();
		// // $datos['ReCliente']=$this->agendaF_model->BuscarCliente();
		// $datos['ReServicios']=$this->agendaF_model->BuscarServicios();
		// $datos['RePromocionesInstitucionales']=$this->agendaF_model->BuscarPromocionesinstitucionales();
		// $datos['RePromocionesLocales']=$this->agendaF_model->BuscarPromocionesLocales();
		 $datos['ReEstatusCita']=$this->agendaF_model->BuscarEstatusCita();
		$this->load->view('agenda/franquiciatario/agregarcitaF_view', $datos);
		$this->load->view('layout/footer');

	
	}
}
 //Esta funcion se uiliza para la vista agenda agregarCita_view
	public function guardar(){

		if(isset($_POST['txt_observaciones']))
		{
			$observaciones=$this->input->post('txt_observaciones');
		}else{
			$observaciones="";
		}
		
		$data['Franquicias']=$this->agendaF_model->BuscarFranquicia();
		foreach ($data['Franquicias'] as $i => $Franquicias) 
		$parametro['Clientes_IdClientes']= $this->input->post('idcliente');
		$parametro['Categoria_IdCategoria']= '7';
		$parametro['ServiciosFranquicias_IdServiciosFranquicias']= $this->input->post('idservi');
		//$parametro['ServiciosFranquicias_IdServiciosFranquicias']= $this->input->post('idserviGM');
		$parametro['Promociones_IdPromociones']= $this->input->post('idpromo');
	   // $parametro['Promociones_IdPromociones']= $this->input->post('idpromoInst');
		$parametro['Fecha']= $this->input->post('txtfecha');
		$parametro['HoraInicio']= $this->input->post('txthorai');
		$parametro['HoraFin']= $this->input->post('txthoraf');
		$parametro['Cabina_IdCabina']= $this->input->post('txt_cabina');
		$parametro['estatuscitas_IdEstatusCita']= $this->input->post('txtstatus');
		$parametro['Observaciones']=$observaciones; 
		$parametro['Franquicias_IdFranquicias']= $i;
		$parametro['Usuarios_IdUsuarios']= $this->input->post('txtusuario');
	


		$this->agendaF_model->guardar($parametro);

		redirect('agenda/franquiciatario/listacitasF', 'refresh');

	}
	public function nuevaCita(){

		
		$data['Franquicias']=$this->agendaF_model->BuscarFranquicia();
		foreach ($data['Franquicias'] as $i => $Franquicias) 
		$parametro['Clientes_IdClientes']= $_POST['cliente'];
		$parametro['Categoria_IdCategoria']= '7';
		$parametro['ServiciosFranquicias_IdServiciosFranquicias']=$_POST['servicio'];
		//$parametro['ServiciosFranquicias_IdServiciosFranquicias']= $this->input->post('idserviGM');
		$parametro['Promociones_IdPromociones']= $_POST['promocion'];
	   // $parametro['Promociones_IdPromociones']= $this->input->post('idpromoInst');
		$parametro['Fecha']=$_POST['fecha'];
		$parametro['HoraInicio']= date("H:i:s", strtotime($_POST['inicio']));
		$parametro['HoraFin']= date("H:i:s", strtotime($_POST['fin']));
		$parametro['Cabina_IdCabina']= $_POST['cabina'];
		$parametro['estatuscitas_IdEstatusCita']= $_POST['status'];
		$parametro['Observaciones']=$_POST['observaciones'];
		$parametro['Franquicias_IdFranquicias']= $i;
		$parametro['Usuarios_IdUsuarios']= $_POST['cosmetologo'];
	

		$datos=$this->agendaF_model->nuevaCita($parametro);
		if($datos==TRUE)
		{
			$this->getEventos();
		}

	}






	public function updEvento2(){
		$data['idCabina'] =  $this->input->post('idCabinaA');
		$data['nombreCliente'] =  $this->input->post('nombreClienteA');
		// $data['idCategoria'] =  $this->input->post('idCategoriaA');
		$data['codePromo'] =  $this->input->post('codePromoA');
		$data['codeService'] =  $this->input->post('codeServiceA');
		$data['fechaAgendada'] =  $this->input->post('fechaAgendadaA');
		$data['horaInicio'] =  $this->input->post('hourStart');
		$data['horaFin'] =  $this->input->post('hourEnd');
		$data['estado'] =  $this->input->post('status') ;
		$data['descripcion'] =  $this->input->post('script');
		$data['idUserChange'] =  $this->input->post('user');
		$data['idEvento'] =  $this->input->post('idEventoA');


		$request = $this->agendaF_model->updEvento2($data);
		echo json_encode($request);
	}

	public function buscarporfranquicia (){ 
	if($this->session->userdata('Rol_IdRol')==FALSE || 
			$this->session->userdata('Rol_IdRol') == '1'|| 
			$this->session->userdata('Rol_IdRol') == '3')
		{
			redirect(base_url().'acceso/acceso');
		} else {
		$this->db->select('*');
	$this->db->join('franquicias','Franquicias_IdFranquicias = IdFranquicias','inner');
		$data = array();
		$query = $this->input->get('query', TRUE);
		if ($query) {
			$result = $this->agendaF_model->buscarporfranquicia(trim($query));
			
			if ($result != FALSE){
				$data = array(
					'result' => $result,
					
);
			}else  {
				$data = array('result' => '');
			}	
		}else{
			$data = array('result' => '');
		}

		$this->load->view('layout/headerFran');
		$this->load->view('layout/menuFranquicia');
		$data['ReFranq']=$this->agendaF_model->BuscarFranq();
		$this->load->view('agenda/franquiciatario/buscarAgendaF_view', $data);
		$this->load->view('layout/footer');
	}
}

	public function citasCanceladas()
	{
		if($this->session->userdata('Rol_IdRol')==FALSE || 
			$this->session->userdata('Rol_IdRol') == '1'|| 
			$this->session->userdata('Rol_IdRol') == '3')
		{
			redirect(base_url().'acceso/acceso');
		} else {
		//  $data['Franquicias']=$this->agendaF_model->BuscarFranquicia();
		// foreach ($data['Franquicias'] as $i => $Franquicias) 
		// $this->db->select('*');
		// //$this->db->from('agenda');
		// $this->db->join('franquicias','Franquicias_IdFranquicias=IdFranquicias','inner');
	    // $this->db->join('categoria','Categoria_IdCategoria = IdCategoria','inner');
	    // $this->db->join('cabina','Cabina_IdCabina = IdCabina','inner');
        // $this->db->join('clientes','Clientes_IdClientes = IdClientes','inner');
		// $this->db->where('IdFranquicias',$i);
		// $this->db->where('estatuscitas_IdEstatusCita = 3');
		// $data['consulta']=$this->db->get('agenda')->result();
		// $data['consulta2']=$this->agendaF_model->BuscarServiciosFranquicias();
    	// $data['consulta3']=$this->agendaF_model->BuscarServiciosGeneral();
		// $data['consulta4']=$this->agendaF_model->Buscarpromos();
		$data['ReCabina']=$this->agendaF_model->BuscarCabina(); 
		$data['ReEstatusCita']=$this->agendaF_model->BuscarEstatusCita();
		$this->load->view('layout/headerFran');
		$this->load->view('layout/menuFranquicia');
		$this->load->view('agenda/franquiciatario/citasCanceladasF_view', $data);
		$this->load->view('layout/footer');
		}
	}
	public function buscarCitas()
	{
		if($this->session->userdata('Rol_IdRol')==FALSE || 
			$this->session->userdata('Rol_IdRol') == '1'|| 
			$this->session->userdata('Rol_IdRol') == '3')
		{
			redirect(base_url().'acceso/acceso');
		} else {
			$inicio=date("Y-m-d", strtotime($_POST['finicio']));
			$fin=date("Y-m-d", strtotime($_POST['ffin']));
			$cabina=$_POST['cabina'];
			$status=$_POST['status'];

				$citas=$this->agendaF_model->buscarCitas($inicio, $fin, $cabina, $status);
			
		}
	}
}